+{
   locale_version => 1.01,
   entry => <<'ENTRY', # for DUCET v6.3.0
010D      ; [.161A.0020.0002] # LATIN SMALL LETTER C WITH CARON
0063 030C ; [.161A.0020.0002] # LATIN SMALL LETTER C WITH CARON
010C      ; [.161A.0020.0008] # LATIN CAPITAL LETTER C WITH CARON
0043 030C ; [.161A.0020.0008] # LATIN CAPITAL LETTER C WITH CARON
0063 0068 ; [.16B1.0020.0002] # <LATIN SMALL LETTER C, LATIN SMALL LETTER H>
0063 0048 ; [.16B1.0020.0007][.0000.0000.0002] # <LATIN SMALL LETTER C, LATIN CAPITAL LETTER H>
0043 0068 ; [.16B1.0020.0007][.0000.0000.0008] # <LATIN CAPITAL LETTER C, LATIN SMALL LETTER H>
0043 0048 ; [.16B1.0020.0008] # <LATIN CAPITAL LETTER C, LATIN CAPITAL LETTER H>
0159      ; [.17BA.0020.0002] # LATIN SMALL LETTER R WITH CARON
0072 030C ; [.17BA.0020.0002] # LATIN SMALL LETTER R WITH CARON
0158      ; [.17BA.0020.0008] # LATIN CAPITAL LETTER R WITH CARON
0052 030C ; [.17BA.0020.0008] # LATIN CAPITAL LETTER R WITH CARON
0161      ; [.17F0.0020.0002] # LATIN SMALL LETTER S WITH CARON
0073 030C ; [.17F0.0020.0002] # LATIN SMALL LETTER S WITH CARON
0160      ; [.17F0.0020.0008] # LATIN CAPITAL LETTER S WITH CARON
0053 030C ; [.17F0.0020.0008] # LATIN CAPITAL LETTER S WITH CARON
017E      ; [.1892.0020.0002] # LATIN SMALL LETTER Z WITH CARON
007A 030C ; [.1892.0020.0002] # LATIN SMALL LETTER Z WITH CARON
017D      ; [.1892.0020.0008] # LATIN CAPITAL LETTER Z WITH CARON
005A 030C ; [.1892.0020.0008] # LATIN CAPITAL LETTER Z WITH CARON
ENTRY
};
