+{
   locale_version => 1.01,
   entry => <<'ENTRY', # for DUCET v6.3.0
025B      ; [.1649.0020.0002] # LATIN SMALL LETTER OPEN E
0190      ; [.1649.0020.0008] # LATIN CAPITAL LETTER OPEN E
2107      ; [.1649.0020.000A] # EULER CONSTANT
1D4B      ; [.1649.0020.0014] # MODIFIER LETTER SMALL OPEN E
0254      ; [.176D.0021.0002] # LATIN SMALL LETTER OPEN O
0186      ; [.176D.0021.0008] # LATIN CAPITAL LETTER OPEN O
1D53      ; [.176D.0021.0014] # MODIFIER LETTER SMALL OPEN O
ENTRY
};
