+{
   locale_version => 1.01,
# eng, g-stroke, t-stroke don't require tailoring
   entry => <<'ENTRY', # for DUCET v6.3.0
00E1      ; [.1600.0020.0002] # LATIN SMALL LETTER A WITH ACUTE
0061 0301 ; [.1600.0020.0002] # LATIN SMALL LETTER A WITH ACUTE
0061 0341 ; [.1600.0020.0002] # LATIN SMALL LETTER A WITH ACUTE
00C1      ; [.1600.0020.0008] # LATIN CAPITAL LETTER A WITH ACUTE
0041 0301 ; [.1600.0020.0008] # LATIN CAPITAL LETTER A WITH ACUTE
0041 0341 ; [.1600.0020.0008] # LATIN CAPITAL LETTER A WITH ACUTE
010D      ; [.162A.0020.0002] # LATIN SMALL LETTER C WITH CARON
0063 030C ; [.162A.0020.0002] # LATIN SMALL LETTER C WITH CARON
010C      ; [.162A.0020.0008] # LATIN CAPITAL LETTER C WITH CARON
0043 030C ; [.162A.0020.0008] # LATIN CAPITAL LETTER C WITH CARON
0292      ; [.162B.0020.0002] # LATIN SMALL LETTER EZH
01B7      ; [.162B.0020.0008] # LATIN CAPITAL LETTER EZH
01EF      ; [.162C.0020.0002] # LATIN SMALL LETTER EZH WITH CARON
0292 030C ; [.162C.0020.0002] # LATIN SMALL LETTER EZH WITH CARON
01EE      ; [.162C.0020.0008] # LATIN CAPITAL LETTER EZH WITH CARON
01B7 030C ; [.162C.0020.0008] # LATIN CAPITAL LETTER EZH WITH CARON
0111      ; [.1647.0020.0002] # LATIN SMALL LETTER D WITH STROKE
0064 0335 ; [.1647.0020.0002] # LATIN SMALL LETTER D WITH STROKE
0110      ; [.1647.0020.0008] # LATIN CAPITAL LETTER D WITH STROKE
0044 0335 ; [.1647.0020.0008] # LATIN CAPITAL LETTER D WITH STROKE
00F0      ; [.1647.0021.0002] # LATIN SMALL LETTER ETH
1DD9      ; [.1647.0021.0002] # COMBINING LATIN SMALL LETTER ETH
00D0      ; [.1647.0021.0008] # LATIN CAPITAL LETTER ETH
01E7      ; [.1698.0020.0002] # LATIN SMALL LETTER G WITH CARON
0067 030C ; [.1698.0020.0002] # LATIN SMALL LETTER G WITH CARON
01E6      ; [.1698.0020.0008] # LATIN CAPITAL LETTER G WITH CARON
0047 030C ; [.1698.0020.0008] # LATIN CAPITAL LETTER G WITH CARON
01E9      ; [.170C.0020.0002] # LATIN SMALL LETTER K WITH CARON
006B 030C ; [.170C.0020.0002] # LATIN SMALL LETTER K WITH CARON
01E8      ; [.170C.0020.0008] # LATIN CAPITAL LETTER K WITH CARON
004B 030C ; [.170C.0020.0008] # LATIN CAPITAL LETTER K WITH CARON
0144      ; [.1769.0021.0002] # LATIN SMALL LETTER N WITH ACUTE
006E 0301 ; [.1769.0021.0002] # LATIN SMALL LETTER N WITH ACUTE
006E 0341 ; [.1769.0021.0002] # LATIN SMALL LETTER N WITH ACUTE
0143      ; [.1769.0021.0008] # LATIN CAPITAL LETTER N WITH ACUTE
004E 0301 ; [.1769.0021.0008] # LATIN CAPITAL LETTER N WITH ACUTE
004E 0341 ; [.1769.0021.0008] # LATIN CAPITAL LETTER N WITH ACUTE
00F1      ; [.1769.0022.0002] # LATIN SMALL LETTER N WITH TILDE
006E 0303 ; [.1769.0022.0002] # LATIN SMALL LETTER N WITH TILDE
00D1      ; [.1769.0022.0008] # LATIN CAPITAL LETTER N WITH TILDE
004E 0303 ; [.1769.0022.0008] # LATIN CAPITAL LETTER N WITH TILDE
0161      ; [.1811.0020.0002] # LATIN SMALL LETTER S WITH CARON
0073 030C ; [.1811.0020.0002] # LATIN SMALL LETTER S WITH CARON
0160      ; [.1811.0020.0008] # LATIN CAPITAL LETTER S WITH CARON
0053 030C ; [.1811.0020.0008] # LATIN CAPITAL LETTER S WITH CARON
00FE      ; [.1817.0021.0002] # LATIN SMALL LETTER THORN
00DE      ; [.1817.0021.0008] # LATIN CAPITAL LETTER THORN
00FC      ; [.187C.0021.0002] # LATIN SMALL LETTER U WITH DIAERESIS
0075 0308 ; [.187C.0021.0002] # LATIN SMALL LETTER U WITH DIAERESIS
00DC      ; [.187C.0021.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS
0055 0308 ; [.187C.0021.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS
01DC      ; [.187C.0021.0002][.0000.0025.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
01DB      ; [.187C.0021.0008][.0000.0025.0002] # LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
01D8      ; [.187C.0021.0002][.0000.0024.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
01D7      ; [.187C.0021.0008][.0000.0024.0002] # LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
01D6      ; [.187C.0021.0002][.0000.0032.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND MACRON
01D5      ; [.187C.0021.0008][.0000.0032.0002] # LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON
01DA      ; [.187C.0021.0002][.0000.0028.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND CARON
01D9      ; [.187C.0021.0008][.0000.0028.0002] # LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON
0171      ; [.187C.0022.0002] # LATIN SMALL LETTER U WITH DOUBLE ACUTE
0075 030B ; [.187C.0022.0002] # LATIN SMALL LETTER U WITH DOUBLE ACUTE
0170      ; [.187C.0022.0008] # LATIN CAPITAL LETTER U WITH DOUBLE ACUTE
0055 030B ; [.187C.0022.0008] # LATIN CAPITAL LETTER U WITH DOUBLE ACUTE
017E      ; [.18FE.0020.0002] # LATIN SMALL LETTER Z WITH CARON
007A 030C ; [.18FE.0020.0002] # LATIN SMALL LETTER Z WITH CARON
017D      ; [.18FE.0020.0008] # LATIN CAPITAL LETTER Z WITH CARON
005A 030C ; [.18FE.0020.0008] # LATIN CAPITAL LETTER Z WITH CARON
00F8      ; [.18FF.0020.0002] # LATIN SMALL LETTER O WITH STROKE
006F 0338 ; [.18FF.0020.0002] # LATIN SMALL LETTER O WITH STROKE
00D8      ; [.18FF.0020.0008] # LATIN CAPITAL LETTER O WITH STROKE
004F 0338 ; [.18FF.0020.0008] # LATIN CAPITAL LETTER O WITH STROKE
01FF      ; [.18FF.0020.0002][.0000.0024.0002] # LATIN SMALL LETTER O WITH STROKE AND ACUTE
01FE      ; [.18FF.0020.0008][.0000.0024.0002] # LATIN CAPITAL LETTER O WITH STROKE AND ACUTE
0153      ; [.18FF.0021.0002] # LATIN SMALL LIGATURE OE
0152      ; [.18FF.0021.0008] # LATIN CAPITAL LIGATURE OE
00E6      ; [.1900.0020.0002] # LATIN SMALL LETTER AE
1DD4      ; [.1900.0020.0002] # COMBINING LATIN SMALL LETTER AE
00C6      ; [.1900.0020.0008] # LATIN CAPITAL LETTER AE
1D2D      ; [.1900.0020.0014] # MODIFIER LETTER CAPITAL AE
01FD      ; [.1900.0020.0002][.0000.0024.0002] # LATIN SMALL LETTER AE WITH ACUTE
01FC      ; [.1900.0020.0008][.0000.0024.0002] # LATIN CAPITAL LETTER AE WITH ACUTE
01E3      ; [.1900.0020.0002][.0000.0032.0002] # LATIN SMALL LETTER AE WITH MACRON
01E2      ; [.1900.0020.0008][.0000.0032.0002] # LATIN CAPITAL LETTER AE WITH MACRON
00E5      ; [.1902.0020.0002] # LATIN SMALL LETTER A WITH RING ABOVE
0061 030A ; [.1902.0020.0002] # LATIN SMALL LETTER A WITH RING ABOVE
00C5      ; [.1902.0020.0008] # LATIN CAPITAL LETTER A WITH RING ABOVE
0041 030A ; [.1902.0020.0008] # LATIN CAPITAL LETTER A WITH RING ABOVE
212B      ; [.1902.0020.0008] # ANGSTROM SIGN
01FB      ; [.1902.0020.0002][.0000.0024.0002] # LATIN SMALL LETTER A WITH RING ABOVE AND ACUTE
01FA      ; [.1902.0020.0008][.0000.0024.0002] # LATIN CAPITAL LETTER A WITH RING ABOVE AND ACUTE
0227      ; [.1902.0021.0002] # LATIN SMALL LETTER A WITH DOT ABOVE
0061 0307 ; [.1902.0021.0002] # LATIN SMALL LETTER A WITH DOT ABOVE
0226      ; [.1902.0021.0008] # LATIN CAPITAL LETTER A WITH DOT ABOVE
0041 0307 ; [.1902.0021.0008] # LATIN CAPITAL LETTER A WITH DOT ABOVE
00E4      ; [.1903.0020.0002] # LATIN SMALL LETTER A WITH DIAERESIS
0061 0308 ; [.1903.0020.0002] # LATIN SMALL LETTER A WITH DIAERESIS
00C4      ; [.1903.0020.0008] # LATIN CAPITAL LETTER A WITH DIAERESIS
0041 0308 ; [.1903.0020.0008] # LATIN CAPITAL LETTER A WITH DIAERESIS
01DF      ; [.1903.0020.0002][.0000.0032.0002] # LATIN SMALL LETTER A WITH DIAERESIS AND MACRON
01DE      ; [.1903.0020.0008][.0000.0032.0002] # LATIN CAPITAL LETTER A WITH DIAERESIS AND MACRON
00E3      ; [.1903.0021.0002] # LATIN SMALL LETTER A WITH TILDE
0061 0303 ; [.1903.0021.0002] # LATIN SMALL LETTER A WITH TILDE
00C3      ; [.1903.0021.0008] # LATIN CAPITAL LETTER A WITH TILDE
0041 0303 ; [.1903.0021.0008] # LATIN CAPITAL LETTER A WITH TILDE
00F6      ; [.1904.0020.0002] # LATIN SMALL LETTER O WITH DIAERESIS
006F 0308 ; [.1904.0020.0002] # LATIN SMALL LETTER O WITH DIAERESIS
00D6      ; [.1904.0020.0008] # LATIN CAPITAL LETTER O WITH DIAERESIS
004F 0308 ; [.1904.0020.0008] # LATIN CAPITAL LETTER O WITH DIAERESIS
022B      ; [.1904.0020.0002][.0000.0032.0002] # LATIN SMALL LETTER O WITH DIAERESIS AND MACRON
022A      ; [.1904.0020.0008][.0000.0032.0002] # LATIN CAPITAL LETTER O WITH DIAERESIS AND MACRON
0151      ; [.1904.0021.0002] # LATIN SMALL LETTER O WITH DOUBLE ACUTE
006F 030B ; [.1904.0021.0002] # LATIN SMALL LETTER O WITH DOUBLE ACUTE
0150      ; [.1904.0021.0008] # LATIN CAPITAL LETTER O WITH DOUBLE ACUTE
004F 030B ; [.1904.0021.0008] # LATIN CAPITAL LETTER O WITH DOUBLE ACUTE
00F5      ; [.1904.0022.0002] # LATIN SMALL LETTER O WITH TILDE
006F 0303 ; [.1904.0022.0002] # LATIN SMALL LETTER O WITH TILDE
00D5      ; [.1904.0022.0008] # LATIN CAPITAL LETTER O WITH TILDE
004F 0303 ; [.1904.0022.0008] # LATIN CAPITAL LETTER O WITH TILDE
1E4D      ; [.1904.0022.0002][.0000.0024.0002] # LATIN SMALL LETTER O WITH TILDE AND ACUTE
1E4C      ; [.1904.0022.0008][.0000.0024.0002] # LATIN CAPITAL LETTER O WITH TILDE AND ACUTE
022D      ; [.1904.0022.0002][.0000.0032.0002] # LATIN SMALL LETTER O WITH TILDE AND MACRON
022C      ; [.1904.0022.0008][.0000.0032.0002] # LATIN CAPITAL LETTER O WITH TILDE AND MACRON
1E4F      ; [.1904.0022.0002][.0000.002B.0002] # LATIN SMALL LETTER O WITH TILDE AND DIAERESIS
1E4E      ; [.1904.0022.0008][.0000.002B.0002] # LATIN CAPITAL LETTER O WITH TILDE AND DIAERESIS
1EE1      ; [.1904.0022.0002][.0000.003F.0002] # LATIN SMALL LETTER O WITH HORN AND TILDE
1EE0      ; [.1904.0022.0008][.0000.003F.0002] # LATIN CAPITAL LETTER O WITH HORN AND TILDE
00F4      ; [.1904.0023.0002] # LATIN SMALL LETTER O WITH CIRCUMFLEX
006F 0302 ; [.1904.0023.0002] # LATIN SMALL LETTER O WITH CIRCUMFLEX
00D4      ; [.1904.0023.0008] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX
004F 0302 ; [.1904.0023.0008] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX
1ED3      ; [.1904.0023.0002][.0000.0025.0002] # LATIN SMALL LETTER O WITH CIRCUMFLEX AND GRAVE
1ED2      ; [.1904.0023.0008][.0000.0025.0002] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND GRAVE
1ED1      ; [.1904.0023.0002][.0000.0024.0002] # LATIN SMALL LETTER O WITH CIRCUMFLEX AND ACUTE
1ED0      ; [.1904.0023.0008][.0000.0024.0002] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND ACUTE
1ED7      ; [.1904.0023.0002][.0000.002D.0002] # LATIN SMALL LETTER O WITH CIRCUMFLEX AND TILDE
1ED6      ; [.1904.0023.0008][.0000.002D.0002] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND TILDE
1ED5      ; [.1904.0023.0002][.0000.003B.0002] # LATIN SMALL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE
1ED4      ; [.1904.0023.0008][.0000.003B.0002] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE
1ED9      ; [.1904.0023.0002][.0000.0042.0002] # LATIN SMALL LETTER O WITH CIRCUMFLEX AND DOT BELOW
1ED8      ; [.1904.0023.0008][.0000.0042.0002] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND DOT BELOW
01EB      ; [.1904.0024.0002] # LATIN SMALL LETTER O WITH OGONEK
006F 0328 ; [.1904.0024.0002] # LATIN SMALL LETTER O WITH OGONEK
01EA      ; [.1904.0024.0008] # LATIN CAPITAL LETTER O WITH OGONEK
004F 0328 ; [.1904.0024.0008] # LATIN CAPITAL LETTER O WITH OGONEK
ENTRY
};
