+{
   locale_version => 1.01,
   entry => <<'ENTRY', # for DUCET v6.3.0
0101      ; [.15EB.001C.0002] # LATIN SMALL LETTER A WITH MACRON
0061 0304 ; [.15EB.001C.0002] # LATIN SMALL LETTER A WITH MACRON
0100      ; [.15EB.001C.0008] # LATIN CAPITAL LETTER A WITH MACRON
0041 0304 ; [.15EB.001C.0008] # LATIN CAPITAL LETTER A WITH MACRON
00E1      ; [.15EB.001D.0002] # LATIN SMALL LETTER A WITH ACUTE
0061 0301 ; [.15EB.001D.0002] # LATIN SMALL LETTER A WITH ACUTE
0061 0341 ; [.15EB.001D.0002] # LATIN SMALL LETTER A WITH ACUTE
00C1      ; [.15EB.001D.0008] # LATIN CAPITAL LETTER A WITH ACUTE
0041 0301 ; [.15EB.001D.0008] # LATIN CAPITAL LETTER A WITH ACUTE
0041 0341 ; [.15EB.001D.0008] # LATIN CAPITAL LETTER A WITH ACUTE
01CE      ; [.15EB.001E.0002] # LATIN SMALL LETTER A WITH CARON
0061 030C ; [.15EB.001E.0002] # LATIN SMALL LETTER A WITH CARON
01CD      ; [.15EB.001E.0008] # LATIN CAPITAL LETTER A WITH CARON
0041 030C ; [.15EB.001E.0008] # LATIN CAPITAL LETTER A WITH CARON
00E0      ; [.15EB.001F.0002] # LATIN SMALL LETTER A WITH GRAVE
0061 0300 ; [.15EB.001F.0002] # LATIN SMALL LETTER A WITH GRAVE
0061 0340 ; [.15EB.001F.0002] # LATIN SMALL LETTER A WITH GRAVE
00C0      ; [.15EB.001F.0008] # LATIN CAPITAL LETTER A WITH GRAVE
0041 0300 ; [.15EB.001F.0008] # LATIN CAPITAL LETTER A WITH GRAVE
0041 0340 ; [.15EB.001F.0008] # LATIN CAPITAL LETTER A WITH GRAVE
0113      ; [.1648.001C.0002] # LATIN SMALL LETTER E WITH MACRON
0065 0304 ; [.1648.001C.0002] # LATIN SMALL LETTER E WITH MACRON
0112      ; [.1648.001C.0008] # LATIN CAPITAL LETTER E WITH MACRON
0045 0304 ; [.1648.001C.0008] # LATIN CAPITAL LETTER E WITH MACRON
00E9      ; [.1648.001D.0002] # LATIN SMALL LETTER E WITH ACUTE
0065 0301 ; [.1648.001D.0002] # LATIN SMALL LETTER E WITH ACUTE
0065 0341 ; [.1648.001D.0002] # LATIN SMALL LETTER E WITH ACUTE
00C9      ; [.1648.001D.0008] # LATIN CAPITAL LETTER E WITH ACUTE
0045 0301 ; [.1648.001D.0008] # LATIN CAPITAL LETTER E WITH ACUTE
0045 0341 ; [.1648.001D.0008] # LATIN CAPITAL LETTER E WITH ACUTE
011B      ; [.1648.001E.0002] # LATIN SMALL LETTER E WITH CARON
0065 030C ; [.1648.001E.0002] # LATIN SMALL LETTER E WITH CARON
011A      ; [.1648.001E.0008] # LATIN CAPITAL LETTER E WITH CARON
0045 030C ; [.1648.001E.0008] # LATIN CAPITAL LETTER E WITH CARON
00E8      ; [.1648.001F.0002] # LATIN SMALL LETTER E WITH GRAVE
0065 0300 ; [.1648.001F.0002] # LATIN SMALL LETTER E WITH GRAVE
0065 0340 ; [.1648.001F.0002] # LATIN SMALL LETTER E WITH GRAVE
00C8      ; [.1648.001F.0008] # LATIN CAPITAL LETTER E WITH GRAVE
0045 0300 ; [.1648.001F.0008] # LATIN CAPITAL LETTER E WITH GRAVE
0045 0340 ; [.1648.001F.0008] # LATIN CAPITAL LETTER E WITH GRAVE
00EA 0304 ; [.1648.0021.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING MACRON>
00CA 0304 ; [.1648.0021.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING MACRON>
0065 0302 0304 ; [.1648.0021.0002] # <LATIN SMALL LETTER E, COMBINING CIRCUMFLEX ACCENT, COMBINING MACRON>
0045 0302 0304 ; [.1648.0021.0008] # <LATIN CAPITAL LETTER E, COMBINING CIRCUMFLEX ACCENT, COMBINING MACRON>
1EBF      ; [.1648.0022.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE
0065 0302 0301 ; [.1648.0022.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE
0065 0302 0341 ; [.1648.0022.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE
1EBE      ; [.1648.0022.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE
0045 0302 0301 ; [.1648.0022.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE
0045 0302 0341 ; [.1648.0022.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE
00EA 0301 ; [.1648.0022.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING ACUTE ACCENT>
00EA 0341 ; [.1648.0022.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING ACUTE TONE MARK>
00CA 0301 ; [.1648.0022.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING ACUTE ACCENT>
00CA 0341 ; [.1648.0022.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING ACUTE TONE MARK>
00EA 030C ; [.1648.0023.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING CARON>
00CA 030C ; [.1648.0023.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING CARON>
0065 0302 030C ; [.1648.0023.0002] # <LATIN SMALL LETTER E, COMBINING CIRCUMFLEX ACCENT, COMBINING CARON>
0045 0302 030C ; [.1648.0023.0008] # <LATIN CAPITAL LETTER E, COMBINING CIRCUMFLEX ACCENT, COMBINING CARON>
1EC1      ; [.1648.0024.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE
0065 0302 0300 ; [.1648.0024.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE
0065 0302 0340 ; [.1648.0024.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE
1EC0      ; [.1648.0024.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE
0045 0302 0300 ; [.1648.0024.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE
0045 0302 0340 ; [.1648.0024.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE
00EA 0300 ; [.1648.0024.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING GRAVE ACCENT>
00EA 0340 ; [.1648.0024.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING GRAVE TONE MARK>
00CA 0300 ; [.1648.0024.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING GRAVE ACCENT>
00CA 0340 ; [.1648.0024.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING GRAVE TONE MARK>
00EA      ; [.1648.0025.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX
0065 0302 ; [.1648.0025.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX
00CA      ; [.1648.0025.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX
0045 0302 ; [.1648.0025.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX
1EC5      ; [.1648.0025.0002][.0000.002D.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND TILDE
1EC4      ; [.1648.0025.0008][.0000.002D.0002] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND TILDE
1EC3      ; [.1648.0025.0002][.0000.003B.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
1EC2      ; [.1648.0025.0008][.0000.003B.0002] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
1EC7      ; [.1648.0025.0002][.0000.0042.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND DOT BELOW
1EC6      ; [.1648.0025.0008][.0000.0042.0002] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND DOT BELOW
012B      ; [.16C9.001C.0002] # LATIN SMALL LETTER I WITH MACRON
0069 0304 ; [.16C9.001C.0002] # LATIN SMALL LETTER I WITH MACRON
012A      ; [.16C9.001C.0008] # LATIN CAPITAL LETTER I WITH MACRON
0049 0304 ; [.16C9.001C.0008] # LATIN CAPITAL LETTER I WITH MACRON
00ED      ; [.16C9.001D.0002] # LATIN SMALL LETTER I WITH ACUTE
0069 0301 ; [.16C9.001D.0002] # LATIN SMALL LETTER I WITH ACUTE
0069 0341 ; [.16C9.001D.0002] # LATIN SMALL LETTER I WITH ACUTE
00CD      ; [.16C9.001D.0008] # LATIN CAPITAL LETTER I WITH ACUTE
0049 0301 ; [.16C9.001D.0008] # LATIN CAPITAL LETTER I WITH ACUTE
0049 0341 ; [.16C9.001D.0008] # LATIN CAPITAL LETTER I WITH ACUTE
01D0      ; [.16C9.001E.0002] # LATIN SMALL LETTER I WITH CARON
0069 030C ; [.16C9.001E.0002] # LATIN SMALL LETTER I WITH CARON
01CF      ; [.16C9.001E.0008] # LATIN CAPITAL LETTER I WITH CARON
0049 030C ; [.16C9.001E.0008] # LATIN CAPITAL LETTER I WITH CARON
00EC      ; [.16C9.001F.0002] # LATIN SMALL LETTER I WITH GRAVE
0069 0300 ; [.16C9.001F.0002] # LATIN SMALL LETTER I WITH GRAVE
0069 0340 ; [.16C9.001F.0002] # LATIN SMALL LETTER I WITH GRAVE
00CC      ; [.16C9.001F.0008] # LATIN CAPITAL LETTER I WITH GRAVE
0049 0300 ; [.16C9.001F.0008] # LATIN CAPITAL LETTER I WITH GRAVE
0049 0340 ; [.16C9.001F.0008] # LATIN CAPITAL LETTER I WITH GRAVE
006D 0304 ; [.173D.001C.0002] # <LATIN SMALL LETTER M, COMBINING MACRON>
004D 0304 ; [.173D.001C.0008] # <LATIN CAPITAL LETTER M, COMBINING MACRON>
1E3F      ; [.173D.001D.0002] # LATIN SMALL LETTER M WITH ACUTE
006D 0301 ; [.173D.001D.0002] # LATIN SMALL LETTER M WITH ACUTE
006D 0341 ; [.173D.001D.0002] # LATIN SMALL LETTER M WITH ACUTE
1E3E      ; [.173D.001D.0008] # LATIN CAPITAL LETTER M WITH ACUTE
004D 0301 ; [.173D.001D.0008] # LATIN CAPITAL LETTER M WITH ACUTE
004D 0341 ; [.173D.001D.0008] # LATIN CAPITAL LETTER M WITH ACUTE
006D 030C ; [.173D.001E.0002] # <LATIN SMALL LETTER M, COMBINING CARON>
004D 030C ; [.173D.001E.0008] # <LATIN CAPITAL LETTER M, COMBINING CARON>
006D 0300 ; [.173D.001F.0002] # <LATIN SMALL LETTER M, COMBINING GRAVE ACCENT>
006D 0340 ; [.173D.001F.0002] # <LATIN SMALL LETTER M, COMBINING GRAVE TONE MARK>
004D 0300 ; [.173D.001F.0008] # <LATIN CAPITAL LETTER M, COMBINING GRAVE ACCENT>
004D 0340 ; [.173D.001F.0008] # <LATIN CAPITAL LETTER M, COMBINING GRAVE TONE MARK>
006E 0304 ; [.174B.001C.0002] # <LATIN SMALL LETTER N, COMBINING MACRON>
004E 0304 ; [.174B.001C.0008] # <LATIN CAPITAL LETTER N, COMBINING MACRON>
0144      ; [.174B.001D.0002] # LATIN SMALL LETTER N WITH ACUTE
006E 0301 ; [.174B.001D.0002] # LATIN SMALL LETTER N WITH ACUTE
006E 0341 ; [.174B.001D.0002] # LATIN SMALL LETTER N WITH ACUTE
0143      ; [.174B.001D.0008] # LATIN CAPITAL LETTER N WITH ACUTE
004E 0301 ; [.174B.001D.0008] # LATIN CAPITAL LETTER N WITH ACUTE
004E 0341 ; [.174B.001D.0008] # LATIN CAPITAL LETTER N WITH ACUTE
0148      ; [.174B.001E.0002] # LATIN SMALL LETTER N WITH CARON
006E 030C ; [.174B.001E.0002] # LATIN SMALL LETTER N WITH CARON
0147      ; [.174B.001E.0008] # LATIN CAPITAL LETTER N WITH CARON
004E 030C ; [.174B.001E.0008] # LATIN CAPITAL LETTER N WITH CARON
01F9      ; [.174B.001F.0002] # LATIN SMALL LETTER N WITH GRAVE
006E 0300 ; [.174B.001F.0002] # LATIN SMALL LETTER N WITH GRAVE
006E 0340 ; [.174B.001F.0002] # LATIN SMALL LETTER N WITH GRAVE
01F8      ; [.174B.001F.0008] # LATIN CAPITAL LETTER N WITH GRAVE
004E 0300 ; [.174B.001F.0008] # LATIN CAPITAL LETTER N WITH GRAVE
004E 0340 ; [.174B.001F.0008] # LATIN CAPITAL LETTER N WITH GRAVE
014D      ; [.176D.001C.0002] # LATIN SMALL LETTER O WITH MACRON
006F 0304 ; [.176D.001C.0002] # LATIN SMALL LETTER O WITH MACRON
014C      ; [.176D.001C.0008] # LATIN CAPITAL LETTER O WITH MACRON
004F 0304 ; [.176D.001C.0008] # LATIN CAPITAL LETTER O WITH MACRON
00F3      ; [.176D.001D.0002] # LATIN SMALL LETTER O WITH ACUTE
006F 0301 ; [.176D.001D.0002] # LATIN SMALL LETTER O WITH ACUTE
006F 0341 ; [.176D.001D.0002] # LATIN SMALL LETTER O WITH ACUTE
00D3      ; [.176D.001D.0008] # LATIN CAPITAL LETTER O WITH ACUTE
004F 0301 ; [.176D.001D.0008] # LATIN CAPITAL LETTER O WITH ACUTE
004F 0341 ; [.176D.001D.0008] # LATIN CAPITAL LETTER O WITH ACUTE
01D2      ; [.176D.001E.0002] # LATIN SMALL LETTER O WITH CARON
006F 030C ; [.176D.001E.0002] # LATIN SMALL LETTER O WITH CARON
01D1      ; [.176D.001E.0008] # LATIN CAPITAL LETTER O WITH CARON
004F 030C ; [.176D.001E.0008] # LATIN CAPITAL LETTER O WITH CARON
00F2      ; [.176D.001F.0002] # LATIN SMALL LETTER O WITH GRAVE
006F 0300 ; [.176D.001F.0002] # LATIN SMALL LETTER O WITH GRAVE
006F 0340 ; [.176D.001F.0002] # LATIN SMALL LETTER O WITH GRAVE
00D2      ; [.176D.001F.0008] # LATIN CAPITAL LETTER O WITH GRAVE
004F 0300 ; [.176D.001F.0008] # LATIN CAPITAL LETTER O WITH GRAVE
004F 0340 ; [.176D.001F.0008] # LATIN CAPITAL LETTER O WITH GRAVE
016B      ; [.1832.001C.0002] # LATIN SMALL LETTER U WITH MACRON
0075 0304 ; [.1832.001C.0002] # LATIN SMALL LETTER U WITH MACRON
016A      ; [.1832.001C.0008] # LATIN CAPITAL LETTER U WITH MACRON
0055 0304 ; [.1832.001C.0008] # LATIN CAPITAL LETTER U WITH MACRON
00FA      ; [.1832.001D.0002] # LATIN SMALL LETTER U WITH ACUTE
0075 0301 ; [.1832.001D.0002] # LATIN SMALL LETTER U WITH ACUTE
0075 0341 ; [.1832.001D.0002] # LATIN SMALL LETTER U WITH ACUTE
00DA      ; [.1832.001D.0008] # LATIN CAPITAL LETTER U WITH ACUTE
0055 0301 ; [.1832.001D.0008] # LATIN CAPITAL LETTER U WITH ACUTE
0055 0341 ; [.1832.001D.0008] # LATIN CAPITAL LETTER U WITH ACUTE
01D4      ; [.1832.001E.0002] # LATIN SMALL LETTER U WITH CARON
0075 030C ; [.1832.001E.0002] # LATIN SMALL LETTER U WITH CARON
01D3      ; [.1832.001E.0008] # LATIN CAPITAL LETTER U WITH CARON
0055 030C ; [.1832.001E.0008] # LATIN CAPITAL LETTER U WITH CARON
00F9      ; [.1832.001F.0002] # LATIN SMALL LETTER U WITH GRAVE
0075 0300 ; [.1832.001F.0002] # LATIN SMALL LETTER U WITH GRAVE
0075 0340 ; [.1832.001F.0002] # LATIN SMALL LETTER U WITH GRAVE
00D9      ; [.1832.001F.0008] # LATIN CAPITAL LETTER U WITH GRAVE
0055 0300 ; [.1832.001F.0008] # LATIN CAPITAL LETTER U WITH GRAVE
0055 0340 ; [.1832.001F.0008] # LATIN CAPITAL LETTER U WITH GRAVE
01D6      ; [.1832.0021.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND MACRON
0075 0308 0304 ; [.1832.0021.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND MACRON
01D5      ; [.1832.0021.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON
0055 0308 0304 ; [.1832.0021.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON
00FC 0304 ; [.1832.0021.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING MACRON>
00DC 0304 ; [.1832.0021.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING MACRON>
01D8      ; [.1832.0022.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
0075 0308 0301 ; [.1832.0022.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
0075 0308 0341 ; [.1832.0022.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
01D7      ; [.1832.0022.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
0055 0308 0301 ; [.1832.0022.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
0055 0308 0341 ; [.1832.0022.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
00FC 0301 ; [.1832.0022.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING ACUTE ACCENT>
00FC 0341 ; [.1832.0022.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING ACUTE TONE MARK>
00DC 0301 ; [.1832.0022.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING ACUTE ACCENT>
00DC 0341 ; [.1832.0022.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING ACUTE TONE MARK>
01DA      ; [.1832.0023.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND CARON
0075 0308 030C ; [.1832.0023.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND CARON
01D9      ; [.1832.0023.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON
0055 0308 030C ; [.1832.0023.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON
00FC 030C ; [.1832.0023.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING CARON>
00DC 030C ; [.1832.0023.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING CARON>
01DC      ; [.1832.0024.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
0075 0308 0300 ; [.1832.0024.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
0075 0308 0340 ; [.1832.0024.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
01DB      ; [.1832.0024.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
0055 0308 0300 ; [.1832.0024.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
0055 0308 0340 ; [.1832.0024.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
00FC 0300 ; [.1832.0024.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING GRAVE ACCENT>
00FC 0340 ; [.1832.0024.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING GRAVE TONE MARK>
00DC 0300 ; [.1832.0024.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING GRAVE ACCENT>
00DC 0340 ; [.1832.0024.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING GRAVE TONE MARK>
00FC      ; [.1832.0025.0002] # LATIN SMALL LETTER U WITH DIAERESIS
0075 0308 ; [.1832.0025.0002] # LATIN SMALL LETTER U WITH DIAERESIS
00DC      ; [.1832.0025.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS
0055 0308 ; [.1832.0025.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS
ENTRY
};
